package com.gxzc.zen.api.sys.service.impl

import com.baomidou.mybatisplus.mapper.EntityWrapper
import com.baomidou.mybatisplus.service.impl.ServiceImpl
import com.gxzc.zen.api.sys.mapper.SysResourceMapper
import com.gxzc.zen.api.sys.model.SysResource
import com.gxzc.zen.api.sys.service.ISysResourceService
import com.gxzc.zen.common.exception.ZenException
import com.gxzc.zen.common.exception.ZenExceptionEnum
import org.springframework.stereotype.Service

/**
 * <p>
 * 资源表 服务实现类
 * </p>
 *
 * @author NorthLan
 * @since 2018-04-28
 */
@Service
class SysResourceServiceImpl : ServiceImpl<SysResourceMapper, SysResource>(), ISysResourceService {

    override fun getResourcesByRoleIds(roleIds: List<Long>): MutableList<SysResource> {
        return baseMapper.selectByRoleIds(roleIds)
    }

    override fun getResourcesByMenuId(menuId: Long): MutableList<SysResource> {
        val condition = SysResource().apply {
            this.menuId = menuId
        }
        return baseMapper.selectList(EntityWrapper(condition))
    }

    override fun insertResource(menuId: Long, sysResource: SysResource): SysResource {
        sysResource.menuId = menuId
        if (baseMapper.insert(sysResource) <= 0) {
            throw ZenException(ZenExceptionEnum.BIZ_INSERT_ERROR)
        }
        return sysResource
    }

    override fun updateResource(sysResource: SysResource): SysResource {
        if (baseMapper.updateById(sysResource) <= 0) {
            throw ZenException(ZenExceptionEnum.BIZ_INSERT_ERROR)
        }
        return sysResource
    }

    override fun deleteResourceById(id: Long) {
        baseMapper.physicalDeleteById(id)
    }

    override fun deleteResourcesByMenuId(menuId: Long) {
        val condition = SysResource().apply {
            this.menuId = menuId
        }
        baseMapper.physicalDelete(EntityWrapper(condition))
    }
}
