package com.gxzc.zen.umps.util

import com.gxzc.zen.api.sys.common.MenuTree
import com.gxzc.zen.api.sys.model.SysRole
import com.gxzc.zen.api.sys.model.SysUser
import com.gxzc.zen.api.sys.service.ISysPermissionService
import com.gxzc.zen.common.util.SpringContextHolder
import com.gxzc.zen.umps.common.ZenPermission
import com.gxzc.zen.umps.constant.ZenHttpSession
import org.apache.shiro.SecurityUtils
import org.apache.shiro.session.Session

/**
 * SSO 工具类
 * @author NorthLan
 * @date 2018/3/15
 * @url https://noahlan.com
 */
@Suppress("UNCHECKED_CAST")
object SSOUtil {
    private var permissionSerivce: ISysPermissionService? = SpringContextHolder.getBean(ISysPermissionService::class.java)

    fun getSession(): Session? {
        return SecurityUtils.getSubject().getSession(false)
    }

    fun setAttribute(key: Any, value: Any?) {
        getSession()?.setAttribute(key, value)
    }

    /**
     * 获取当前登陆 账号
     */
    fun getCurAccount(): String? {
        return SecurityUtils.getSubject().principal?.toString()
    }

    /**
     * 获取当前登陆 userId
     */
    fun getCurUserId(): Long? {
        return getSession()?.getAttribute(ZenHttpSession.SESSION_KEY_USER_ID) as? Long
    }

    /**
     * 获取当前登陆 基本信息
     */
    fun getCurUserInfo(): SysUser? {
        return getSession()?.getAttribute(ZenHttpSession.SESSION_KEY_USER_INFO) as? SysUser
    }

    /**
     * 获取当前登陆 角色列表
     */
    fun getCurUserRoles(): MutableList<SysRole>? {
        return getSession()?.getAttribute(ZenHttpSession.SESSION_KEY_USER_ROLES) as? MutableList<SysRole>
    }

    /**
     * 获取当前用户 权限列表
     */
    fun getCurUserPerms(): MutableList<ZenPermission>? {
        if (permissionSerivce == null) {
            permissionSerivce = SpringContextHolder.getBean(ISysPermissionService::class.java)
        }
        return permissionSerivce!!.getSubjectPermission()
    }

    /**
     * 获取当前用户 目录树
     */
    fun getCurUserMenuTree(platformId: Long): MutableList<MenuTree>? {
        return getSession()?.getAttribute(ZenHttpSession.SESSION_KEY_USER_MENU + platformId) as? MutableList<MenuTree>
    }
}