package com.gxzc.zen.web.sys.controller

import com.gxzc.zen.api.sys.service.ISysRoleService
import com.gxzc.zen.api.sys.service.ISysUserService
import com.gxzc.zen.common.base.BaseController
import com.gxzc.zen.common.dto.RequestDto
import com.gxzc.zen.common.dto.ResponseDto
import com.gxzc.zen.common.exception.ZenException
import com.gxzc.zen.common.exception.ZenExceptionEnum
import com.gxzc.zen.common.util.HttpUtil
import com.gxzc.zen.umps.common.ZenAuthToken
import com.gxzc.zen.umps.constant.ZenHttpSession
import io.swagger.annotations.ApiOperation
import org.apache.shiro.SecurityUtils
import org.apache.shiro.authc.AuthenticationException
import org.apache.shiro.authc.UnknownAccountException
import org.slf4j.LoggerFactory
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.*
import javax.servlet.http.Cookie

/**
 * 身份验证相关控制器
 * @author NorthLan
 * @date 2018/2/10
 * @url https://noahlan.com
 */
@RestController
@RequestMapping("auth")
class AuthController : BaseController() {
    companion object {
        private val logger = LoggerFactory.getLogger(AuthController::class.java)
    }

    @Autowired
    private lateinit var userService: ISysUserService

    @Autowired
    private lateinit var roleService: ISysRoleService

    @ApiOperation(value = "登录")
    @PostMapping("/login")
    fun login(@RequestBody data: RequestDto): ResponseEntity<*> {
//        val a = System.currentTimeMillis()
        // 验证输入合法性
        val account = data["account"]?.toString()?.trim() ?: throw ZenException(ZenExceptionEnum.REQUEST_NULL)
        val password = data["password"]?.toString() ?: throw ZenException(ZenExceptionEnum.REQUEST_NULL)
        val rememberMe = data["rememberMe"] as? Boolean ?: false

        val user = userService.getUserByAccount(account)
        try {
            SecurityUtils.getSubject().login(ZenAuthToken(account, password, rememberMe, getRequest().remoteHost, user))
        } catch (e: AuthenticationException) {
            logger.warn("login error,", e)
            throw ZenException(ZenExceptionEnum.AUTH_PASSWORD_ERROR)
        } catch (e: UnknownAccountException) {
//            logger.warn("login error,", e)
            throw ZenException(ZenExceptionEnum.AUTH_ACCOUNT_NOT_EXISTS)
        } finally {
            // 能进到这里来 user 肯定 !=null
            val session = SecurityUtils.getSubject().getSession(false)
            session?.let {
                // ID
                it.setAttribute(ZenHttpSession.SESSION_KEY_USER_ID, user!!.id!!)
                // 用户基本信息
                it.setAttribute(ZenHttpSession.SESSION_KEY_USER_INFO, user)
                // 角色列表
                it.setAttribute(ZenHttpSession.SESSION_KEY_USER_ROLES, roleService.getRoleListByUserId(user.id))
            }
        }
        return ResponseEntity.ok(ResponseDto())
    }

    @ApiOperation("设置cookie")
    @PostMapping("/setcookie")
    fun token(@RequestBody cookies: List<RequestDto>): ResponseEntity<*> {
        cookies.forEach {
            getResponse().addCookie(Cookie(it["name"]?.toString(), it["value"]?.toString()).apply {
                path = "/"
//                secure = it["secure"] as Boolean
//                isHttpOnly = it["httpOnly"] as Boolean
            })
        }
        return ResponseEntity.ok(ResponseDto())
    }

    @ApiOperation("获取cookie")
    @GetMapping("/hello")
    fun hello(): ResponseEntity<*> {
        // 用户是否已经登陆
        return if (SecurityUtils.getSubject().isAuthenticated) {
            val cks = HttpUtil.getRequest().cookies
            val ck = cks?.find {
                it.name == ZenHttpSession.DEFAULT_SESSION_ID_NAME
            }
            if (ck == null) {
                ResponseEntity.ok(null)
            } else {
                ResponseEntity.ok(cks)
            }
        } else {
            ResponseEntity.ok(null)
        }
    }

    @ApiOperation(value = "登出")
    @DeleteMapping("/logout")
    fun logout(): ResponseEntity<*> {
        SecurityUtils.getSubject().logout()
//        SSOHelper.clearLogin(getRequest(), getResponse())
        return ResponseEntity.ok(ResponseDto())
    }
}