package com.gxzc.zen.web.sys.controller

import com.gxzc.zen.api.sys.model.SysResource
import com.gxzc.zen.api.sys.service.ISysResourceService
import com.gxzc.zen.common.base.BaseController
import com.gxzc.zen.common.dto.ResponseDto
import io.swagger.annotations.ApiOperation
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.*

/**
 * 系统资源 管理器
 * @author NorthLan
 * @date 2018/5/2
 * @url https://noahlan.com
 */
@RestController
@RequestMapping("resource")
class ResourceController : BaseController() {

    @Autowired
    private lateinit var resourceService: ISysResourceService

    @ApiOperation("查询关联某菜单的所有资源")
    @GetMapping("menu/{menuId}")
    fun getResourceByMenuId(@PathVariable menuId: Long): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            data = resourceService.getResourcesByMenuId(menuId)
        })
    }

    @ApiOperation("在指定菜单下新增资源")
    @PostMapping("menu/{menuId}")
    fun insertResourceByMenuId(@PathVariable menuId: Long, @RequestBody sysResource: SysResource): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            data = resourceService.insertResource(menuId, sysResource)
        })
    }

    @ApiOperation("删除指定菜单下的所有资源")
    @DeleteMapping("menu/{menuId}")
    fun deleteResourceByMenuId(@PathVariable menuId: Long): ResponseEntity<*> {
        resourceService.deleteResourcesByMenuId(menuId)
        return ResponseEntity.ok(ResponseDto())
    }

    @ApiOperation("删除指定资源")
    @DeleteMapping("{id}")
    fun deleteResourceById(@PathVariable id: Long): ResponseEntity<*> {
        resourceService.deleteResourceById(id)
        return ResponseEntity.ok(ResponseDto())
    }

    @ApiOperation("修改指定资源")
    @PutMapping("{id}")
    fun updateResourceById(@PathVariable id: Long, @RequestBody sysResource: SysResource): ResponseEntity<*> {
        return ResponseEntity.ok(ResponseDto().apply {
            data = resourceService.updateResource(sysResource)
        })
    }
}